==> huaweicloudsdkrgc-3.1.85-py2.py3-none-any.whl: huaweicloudsdkrgc/v1/model/artifact.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class Artifact:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'content': 'Content',
        'type': 'str'
    }

    attribute_map = {
        'content': 'content',
        'type': 'type'
    }

    def __init__(self, content=None, type=None):
        """Artifact

        The model defined in huaweicloud sdk

        :param content: 
        :type content: :class:`huaweicloudsdkrgc.v1.Content`
        :param type: 策略类型。
        :type type: str
        """
        
        

        self._content = None
        self._type = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if type is not None:
            self.type = type

    @property
    def content(self):
        """Gets the content of this Artifact.

        :return: The content of this Artifact.
        :rtype: :class:`huaweicloudsdkrgc.v1.Content`
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this Artifact.

        :param content: The content of this Artifact.
        :type content: :class:`huaweicloudsdkrgc.v1.Content`
        """
        self._content = content

    @property
    def type(self):
        """Gets the type of this Artifact.

        策略类型。

        :return: The type of this Artifact.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Artifact.

        策略类型。

        :param type: The type of this Artifact.
        :type type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Artifact):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrgc-3.1.157-py2.py3-none-any.whl: huaweicloudsdkrgc/v1/model/artifact.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class Artifact:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'content': 'Content',
        'type': 'str'
    }

    attribute_map = {
        'content': 'content',
        'type': 'type'
    }

    def __init__(self, content=None, type=None):
        r"""Artifact

        The model defined in huaweicloud sdk

        :param content: 
        :type content: :class:`huaweicloudsdkrgc.v1.Content`
        :param type: 策略类型。
        :type type: str
        """
        
        

        self._content = None
        self._type = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if type is not None:
            self.type = type

    @property
    def content(self):
        r"""Gets the content of this Artifact.

        :return: The content of this Artifact.
        :rtype: :class:`huaweicloudsdkrgc.v1.Content`
        """
        return self._content

    @content.setter
    def content(self, content):
        r"""Sets the content of this Artifact.

        :param content: The content of this Artifact.
        :type content: :class:`huaweicloudsdkrgc.v1.Content`
        """
        self._content = content

    @property
    def type(self):
        r"""Gets the type of this Artifact.

        策略类型。

        :return: The type of this Artifact.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this Artifact.

        策略类型。

        :param type: The type of this Artifact.
        :type type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Artifact):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
